<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation>Informazioni su %1</translation>
    </message>
    <message>
        <source>&lt;h2&gt;%1 Client %2&lt;/h2&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h5&gt; REV %1 &lt;/h5&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <source>Check For Updates</source>
        <translation>Controlla aggiornamenti</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>failed to open account database</source>
        <translation>Impossibile aprire il database degli account</translation>
    </message>
    <message>
        <source>Authorization expired, please re-login</source>
        <translation>Autorizzazione scaduta, per favore effettua il login</translation>
    </message>
</context>
<context>
    <name>AccountSettingsDialog</name>
    <message>
        <source>Account Settings</source>
        <translation>Impostazioni account</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Inserisci l&apos;indirizzo del server</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 non è un indirizzo valido per il server</translation>
    </message>
    <message>
        <source>Failed to save account information</source>
        <translation>Impossibile salvare le informazioni dell&apos;account</translation>
    </message>
    <message>
        <source>Failed to save the changes: %1</source>
        <translation>Impossibile salvare i cambiamenti: %1</translation>
    </message>
    <message>
        <source>Successfully updated current account information</source>
        <translation>Informazioni dell&apos;attuale account correttamente aggiornate</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <source>Server Address</source>
        <translation>Indirizzo Server</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>AccountView</name>
    <message>
        <source>Are you sure you want to remove account %1?&lt;br&gt;&lt;br&gt;The account will be removed locally. All syncing configuration will be removed too. The account at the server will not be affected.</source>
        <translation>Sei sicuro di voler rimuovere l&apos;account %1?&lt;br&gt;&lt;br&gt;L&apos;account sarà rimosso localmente. Anche tutte le configurazioni di sincronizzazione saranno rimosse. L&apos;account sul server non sarà toccato.</translation>
    </message>
    <message>
        <source>Failed to unsync libraries of this account: %1</source>
        <translation>Impossibile scollegare le librerie dell&apos;account: %1</translation>
    </message>
    <message>
        <source>click to open the website</source>
        <translation>Clicca per aprire il sito web</translation>
    </message>
    <message>
        <source>pro version</source>
        <translation>Versione Pro</translation>
    </message>
    <message>
        <source>No account</source>
        <translation>Nessun account</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Scegli</translation>
    </message>
    <message>
        <source>Account settings</source>
        <translation>Impostazioni account</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Aggiungi un account</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Disconnetti</translation>
    </message>
    <message>
        <source>not logged in</source>
        <translation>non autenticato</translation>
    </message>
    <message>
        <source>Failed to remove local repos sync token: %1</source>
        <translation>Impossibile rimuovere il token di sincronizzazione delle librerie locali: %1</translation>
    </message>
    <message>
        <source>Failed to get repo sync information from server: %1</source>
        <translation>Impossibile ottenere le informazioni di sincronizzazione della libreria dal server: %1 </translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Modulo</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Account</translation>
    </message>
    <message>
        <source>email</source>
        <translation>email</translation>
    </message>
    <message>
        <source>server</source>
        <translation>server</translation>
    </message>
</context>
<context>
    <name>ActivitiesTab</name>
    <message>
        <source>File Activities are only supported in %1 Server Professional Edition.</source>
        <translation>Le Attività File sono supportate soltanto in %1 Server Professional Edition.</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>riprova</translation>
    </message>
    <message>
        <source>Failed to get actvities information. Please %1</source>
        <translation>Impossibile ottenere informazioni sulle attività.&lt;br\&gt;Per favore %1</translation>
    </message>
</context>
<context>
    <name>AutoUpdateManager</name>
    <message>
        <source>Upload Success</source>
        <translation>Caricamento riuscito</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
uploaded successfully.</source>
        <translation>File &quot;%1&quot;
caricato con successo.</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
failed to upload.</source>
        <translation>File &quot;%1&quot;
non caricato a causa di un errore.</translation>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The file is locked by %1, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload Failure: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AvatarService</name>
    <message>
        <source>Failed to create avatars folder</source>
        <translation>Impossibile creare cartella degli avatar</translation>
    </message>
</context>
<context>
    <name>CheckRepoRootDirPermDialog</name>
    <message>
        <source>Checking Permission</source>
        <translation>Controllo i permessi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>CloneTasksDialog</name>
    <message>
        <source>Download tasks</source>
        <translation>Attività di scaricamento</translation>
    </message>
    <message>
        <source>remove all successful tasks</source>
        <translation>rimuovi tutte le attività completate con successo</translation>
    </message>
    <message>
        <source>No download tasks right now.</source>
        <translation>Nessun processo di scaricamento attivo.</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Svuota</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableModel</name>
    <message>
        <source>Library</source>
        <translation>Libreria</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Percorso</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableView</name>
    <message>
        <source>Cancel this task</source>
        <translation>Annulla questa attività</translation>
    </message>
    <message>
        <source>cancel this task</source>
        <translation>annulla questa attività</translation>
    </message>
    <message>
        <source>Remove this task</source>
        <translation>Rimuovi questa attività</translation>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Impossibile annullare questa attività:

 %1</translation>
    </message>
    <message>
        <source>Failed to remove this task:

 %1</source>
        <translation>Impossibile rimuovere questa attività:

%1</translation>
    </message>
</context>
<context>
    <name>CloudView</name>
    <message>
        <source>Minimize</source>
        <translation>Minimizza</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Libraries</source>
        <translation>Librerie</translation>
    </message>
    <message>
        <source>Starred</source>
        <translation>Preferiti</translation>
    </message>
    <message>
        <source>Activities</source>
        <translation>Attività</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ricerca</translation>
    </message>
    <message>
        <source>current download rate</source>
        <translation>velocità di scaricamento attuale</translation>
    </message>
    <message>
        <source>current upload rate</source>
        <translation>velocità di caricamento attuale</translation>
    </message>
    <message>
        <source>Please Choose a folder to sync</source>
        <translation>Per favore Scegli una cartella da sincronizzare</translation>
    </message>
    <message>
        <source>no server connected</source>
        <translation>nessun server connesso</translation>
    </message>
    <message>
        <source>all servers connected</source>
        <translation>tutti i server sono connessi</translation>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>alcuni server non sono connessi</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Modulo</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>minimize</source>
        <translation>minimizza</translation>
    </message>
    <message>
        <source>close</source>
        <translation>chiudi</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Seleziona</translation>
    </message>
    <message>
        <source>brand</source>
        <translation>marchio</translation>
    </message>
    <message>
        <source>or Drop Folder to Sync</source>
        <translation>o trascina qui la cartella per sincronizzarla</translation>
    </message>
    <message>
        <source>download rate</source>
        <translation>velocità di scaricamento</translation>
    </message>
    <message>
        <source>downarrow</source>
        <translation>Freccia Giù</translation>
    </message>
    <message>
        <source>upload rate</source>
        <translation>velocità di caricamento</translation>
    </message>
    <message>
        <source>uparrow</source>
        <translation>Freccia Su</translation>
    </message>
</context>
<context>
    <name>Configurator</name>
    <message>
        <source>Error when creating ccnet configuration</source>
        <translation>Errore nel creare la configurazione ccnet</translation>
    </message>
    <message>
        <source>Unable to create preconfigure directory &quot;%1&quot;</source>
        <translation>Impossibile creare la directory di preconfigurazione &quot;%1&quot;</translation>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation>impossibile leggere %1</translation>
    </message>
</context>
<context>
    <name>CreateRepoDialog</name>
    <message>
        <source>Create a library</source>
        <translation>Crea una libreria</translation>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Scegli una cartella</translation>
    </message>
    <message>
        <source>Creating...</source>
        <translation>Creazione...</translation>
    </message>
    <message>
        <source>Failed to generate encryption key for this library</source>
        <translation>Impossibile generare la chiave di cifratura per questa libreria</translation>
    </message>
    <message>
        <source>Please choose the directory to sync</source>
        <translation>Scegli la cartella da sincronizzare</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>La cartella %1 non esiste</translation>
    </message>
    <message>
        <source>Please enter the name</source>
        <translation>Inserisci il nome</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Inserisci la password</translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation>Le password non corrispondono</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Errore sconosciuto</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>Impossibile aggiungere l&apos;attività di download
%1</translation>
    </message>
    <message>
        <source>Failed to create library on the server:
%1</source>
        <translation>Impossibile creare la libreria sul server:
%1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation>Percorso:</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Scegli</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>encrypted</source>
        <translation>cifrato</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Password:</translation>
    </message>
    <message>
        <source>Password Again:</source>
        <translation>Ripeti la Password:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>testo di stato</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>DaemonManager</name>
    <message>
        <source>failed to load ccnet config dir %1</source>
        <translation>Impossibile caricare la directory di configurazione ccnet %1</translation>
    </message>
    <message>
        <source>%1 client failed to initialize</source>
        <translation>Impossibile inizializzare il client %1</translation>
    </message>
</context>
<context>
    <name>DownloadRepoDialog</name>
    <message>
        <source>Please enter the password</source>
        <translation>Inserire la password</translation>
    </message>
    <message>
        <source>Sync library &quot;%1&quot;</source>
        <translation>Sincronizza la libreria &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync folder &quot;%1&quot;</source>
        <translation>Sincronizza la cartella &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync to folder:</source>
        <translation>Sincronizza con la cartella:</translation>
    </message>
    <message>
        <source>or</source>
        <translation>oppure</translation>
    </message>
    <message>
        <source>sync with an existing folder</source>
        <translation>sincronizza con una cartella esistente</translation>
    </message>
    <message>
        <source>create a new sync folder</source>
        <translation>crea una nuova cartella di sincronizzazione</translation>
    </message>
    <message>
        <source>Sync with this existing folder:</source>
        <translation>Sincronizza con questa cartella esistente:</translation>
    </message>
    <message>
        <source>Please choose a folder</source>
        <translation>Scegli una cartella</translation>
    </message>
    <message>
        <source>The folder does not exist</source>
        <translation>La cartella non esiste</translation>
    </message>
    <message>
        <source>Please choose the folder to sync.</source>
        <translation>Scegli la cartella da sincronizzare.</translation>
    </message>
    <message>
        <source>Your organization disables putting a library outside %1 folder.</source>
        <translation>La tua organizzazione vieta di collocare una libreria al di fuori della cartella %1.</translation>
    </message>
    <message>
        <source>Conflicting with existing file &quot;%1&quot;, please choose a different folder.</source>
        <translation>In conflitto con il file esistente &quot;%1&quot;, scegli un&apos;altra cartella.</translation>
    </message>
    <message>
        <source>Conflicting with existing library &quot;%1&quot;, please choose a different folder.</source>
        <translation>In conflitto con la libreria esistente &quot;%1&quot;, scegli un&apos;altra cartella.</translation>
    </message>
    <message>
        <source>The folder &quot;%1&quot; already exists. Are you sure to sync with it (contents will be merged)?</source>
        <translation>La cartella &quot;%1&quot; esiste già. Vuoi davvero sincronizzare con essa (i contenuti saranno riuniti)?</translation>
    </message>
    <message>
        <source>Click No to sync with a new folder instead</source>
        <translation>Seleziona No per sincronizzare invece con una nuova cartella</translation>
    </message>
    <message>
        <source>Unable to find an alternative folder name</source>
        <translation>Impossibile trovare un nome alternativo per la cartella</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>Impossibile aggiungere l&apos;attività di scaricamento:
%1</translation>
    </message>
    <message>
        <source>Failed to get repo download information:
%1</source>
        <translation>Impossibile ottenere informazioni sullo scaricamento della libreria:
%1</translation>
    </message>
    <message>
        <source>Download Library</source>
        <translation>Scarica libreria</translation>
    </message>
    <message>
        <source>choose...</source>
        <translation>scegli...</translation>
    </message>
    <message>
        <source>Password for this library:</source>
        <translation>Password per questa libreria:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>EventDetailsDialog</name>
    <message>
        <source>Modification Details</source>
        <translation>Dettagli delle modifiche</translation>
    </message>
</context>
<context>
    <name>EventDetailsListModel</name>
    <message>
        <source>Added files</source>
        <translation>File aggiunti</translation>
    </message>
    <message>
        <source>Deleted files</source>
        <translation>File cancellati</translation>
    </message>
    <message>
        <source>Modified files</source>
        <translation>File modificati</translation>
    </message>
    <message>
        <source>Added folders</source>
        <translation>Cartelle aggiunte</translation>
    </message>
    <message>
        <source>Deleted folders</source>
        <translation>Cartelle cancellate</translation>
    </message>
</context>
<context>
    <name>EventDetailsListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Apri</translation>
    </message>
    <message>
        <source>Open &amp;parent folder</source>
        <translation>Apri directory &amp;superiore</translation>
    </message>
</context>
<context>
    <name>FileBrowserDialog</name>
    <message>
        <source>Cloud File Browser</source>
        <translation>Visualizzatore dei file remoti</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Avanti</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <source>Upload files</source>
        <translation>Carica file</translation>
    </message>
    <message>
        <source>Upload a directory</source>
        <translation>Carica una cartella</translation>
    </message>
    <message>
        <source>You don&apos;t have permission to upload files to this library</source>
        <translation>Non hai il permesso di caricare file in questa libreria</translation>
    </message>
    <message>
        <source>Create a folder</source>
        <translation>Crea una cartella</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 oggetti</translation>
    </message>
    <message>
        <source>Folder name</source>
        <translation>Nome della cartella</translation>
    </message>
    <message>
        <source>Invalid folder name!</source>
        <translation>Nome della cartella non valido!</translation>
    </message>
    <message>
        <source>The name &quot;%1&quot; is already taken.</source>
        <translation>Il nome &quot;%1&quot; è già in uso.</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>riprova</translation>
    </message>
    <message>
        <source>Failed to get files information&lt;br/&gt;Please %1</source>
        <translation>Impossibile caricare le informazioni sui file&lt;br/&gt;Per favore %1</translation>
    </message>
    <message>
        <source>This folder is empty.</source>
        <translation>Questa cartella è vuota.</translation>
    </message>
    <message>
        <source>Enter name of file to save to...</source>
        <translation>Inserisci il nome del file per il salvataggio...</translation>
    </message>
    <message>
        <source>Unable to remove file &quot;%1&quot;</source>
        <translation>Impossibile cancellare il file &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Enter the path of the folder you want to save to...</source>
        <translation>Inserisci il percorso della cartella per il salvataggio...</translation>
    </message>
    <message>
        <source>Do you want to overwrite the existing file &quot;%1&quot;?</source>
        <translation>Vuoi sovrascrivere il file esistente &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; haven&apos;t been synced</source>
        <translation>Il file &quot;%1&quot; non è stato sincronizzato</translation>
    </message>
    <message>
        <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
        <translation>Il file %1 esiste già.&lt;br/&gt;Vuoi sovrascriverlo?&lt;br/&gt;&lt;small&gt;(Scegli No per caricarlo usando un altro nome.)&lt;/small&gt;</translation>
    </message>
    <message>
        <source>File does not exist</source>
        <translation>Il file non esiste</translation>
    </message>
    <message>
        <source>Failed to download file: %1</source>
        <translation>Impossibile scaricare il file: %1</translation>
    </message>
    <message>
        <source>Select a file to upload</source>
        <translation>Scegli un file da caricare</translation>
    </message>
    <message>
        <source>Select a directory to upload</source>
        <translation>Scegli una cartella da caricare</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <source>Do you really want to delete these items</source>
        <translation>Vuoi davvero cancellare questi oggetti</translation>
    </message>
    <message>
        <source>Create folder failed</source>
        <translation>Impossibile creare la cartella</translation>
    </message>
    <message>
        <source>Lock file failed</source>
        <translation>Impossibile bloccare il file</translation>
    </message>
    <message>
        <source>Select a file to update %1</source>
        <translation>Scegli un file da caricare %1</translation>
    </message>
    <message>
        <source>Rename failed</source>
        <translation>Impossibile rinominare</translation>
    </message>
    <message>
        <source>Remove failed</source>
        <translation>Impossibile cancellare</translation>
    </message>
    <message>
        <source>Share failed</source>
        <translation>Impossibile condividere</translation>
    </message>
    <message>
        <source>Cannot paste files from the same folder</source>
        <translation>Non puoi incollare file dalla stessa cartella</translation>
    </message>
    <message>
        <source>Cannot paste the folder to its subfolder</source>
        <translation>Non puoi incollare la cartella in una sua sottocartella</translation>
    </message>
    <message>
        <source>Copy failed</source>
        <translation>Impossibile copiare</translation>
    </message>
    <message>
        <source>Move failed</source>
        <translation>Impossibile spostare</translation>
    </message>
    <message>
        <source>Create library failed!</source>
        <translation>Impossibile creare la libreria</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library/Folder not found.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to upload file %1: %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to create cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to open cache folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserProgressDialog</name>
    <message>
        <source>Pending</source>
        <translation>In corso</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Carica</translation>
    </message>
    <message>
        <source>Uploading %1</source>
        <translation>Sto caricando %1</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Scarica</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Sto scaricando %1</translation>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation>%1 di %2</translation>
    </message>
    <message>
        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileNetworkTask</name>
    <message>
        <source>Operation canceled</source>
        <translation>Operazione annullata</translation>
    </message>
    <message>
        <source>pending</source>
        <translation>in corso</translation>
    </message>
</context>
<context>
    <name>FileServerTask</name>
    <message>
        <source>task cancelled</source>
        <translation>attività annullata</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Errore interno del server</translation>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation>La quota di spazio disponibile è stata esaurita</translation>
    </message>
</context>
<context>
    <name>FileTableModel</name>
    <message>
        <source>locked by %1</source>
        <translation>bloccato da %1</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <source>Last Modified</source>
        <translation>Ultima modifica</translation>
    </message>
    <message>
        <source>Kind</source>
        <translation>Tipo</translation>
    </message>
</context>
<context>
    <name>FileTableView</name>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Salva con nome...</translation>
    </message>
    <message>
        <source>&amp;Lock</source>
        <translation>&amp;Blocca</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Rinomina</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Ca&amp;ncella</translation>
    </message>
    <message>
        <source>Share to Group</source>
        <translation>Condividi con il gruppo</translation>
    </message>
    <message>
        <source>&amp;Update</source>
        <translation>&amp;Aggiorna</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;Taglia</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Incolla</translation>
    </message>
    <message>
        <source>Canc&amp;el Download</source>
        <translation>&amp;Annulla scaricamento</translation>
    </message>
    <message>
        <source>&amp;Sync this folder</source>
        <translation>&amp;Sincronizza questa cartella</translation>
    </message>
    <message>
        <source>This feature is available in pro version only
</source>
        <translation>Questa funzionalità è disponibile solo nella versione pro
</translation>
    </message>
    <message>
        <source>&amp;Generate %1 Download Link</source>
        <translation>&amp;Genera il link %1 per scaricare</translation>
    </message>
    <message>
        <source>Share to User</source>
        <translation>Condividi con l&apos;utente</translation>
    </message>
    <message>
        <source>G&amp;enerate %1 Internal Link</source>
        <translation>G&amp;enera il link %1 interno</translation>
    </message>
    <message>
        <source>&amp;Save As To...</source>
        <translation>&amp;Salva col nome in...</translation>
    </message>
    <message>
        <source>Un&amp;lock</source>
        <translation>Sb&amp;locca</translation>
    </message>
    <message>
        <source>Unable to remove readonly files</source>
        <translation>Impossibile cancellare file in sola lettura</translation>
    </message>
    <message>
        <source>Unable to cut readonly files</source>
        <translation>Impossibile tagliare file in sola lettura</translation>
    </message>
    <message>
        <source>Retry Upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete Local Version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Version Save As...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Local Cache Folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GetFileTask</name>
    <message>
        <source>Failed to create folders</source>
        <translation>Impossibile creare le cartelle</translation>
    </message>
    <message>
        <source>Failed to create temporary files</source>
        <translation>Impossibile creare file temporanei</translation>
    </message>
    <message>
        <source>Failed to write file to disk</source>
        <translation>Impossibile scrivere file su disco</translation>
    </message>
    <message>
        <source>Failed to remove the older version of the downloaded file</source>
        <translation>Impossibile rimuovere la versione più vecchia del file scaricato</translation>
    </message>
    <message>
        <source>Failed to move file</source>
        <translation>Impossibile spostare il file</translation>
    </message>
</context>
<context>
    <name>InitSeafileDialog</name>
    <message>
        <source>%1 Initialization</source>
        <translation>%1 Inizializzazione</translation>
    </message>
    <message>
        <source>Choose %1 folder</source>
        <translation>Scegli la cartella %1</translation>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Scegli una cartella</translation>
    </message>
    <message>
        <source>Initialization is not finished. Really quit?</source>
        <translation>Inizializzazione non completata. Vuoi davvero terminare?</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>La cartella %1 non esiste</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Choose a folder</source>
        <translation>Scegli una cartella</translation>
    </message>
    <message>
        <source>Please choose a folder. We will create a %1 subfolder in it. When you download a library, it will be saved there by default.</source>
        <translation>Per favore, scegli una cartella. Al suo interno sarà creata la sottocartella %1. Quando scaricherai una libreria, sarà salvata in quella posizione per default.</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Scegli...</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Prossimo</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancella</translation>
    </message>
</context>
<context>
    <name>InitVirtualDriveDialog</name>
    <message>
        <source>%1 organizes files by libraries.
Do you like to download your default library?</source>
        <translation>%1 organizza i file in librerie.
Vuoi scaricare la tua libreria predefinita?</translation>
    </message>
    <message>
        <source>Checking your default library...</source>
        <translation>Sto verificando la tua libreria predefinita...</translation>
    </message>
    <message>
        <source>Creating the default library...</source>
        <translation>Sto creando la libreria predefinita...</translation>
    </message>
    <message>
        <source>Failed to create default library:

The server version must be 2.1 or higher to support this.</source>
        <translation>Impossibile creare la libreria predefinita:

La versione del server deve essere 2.1 o più alta per supportare questa funzione.</translation>
    </message>
    <message>
        <source>Failed to get default library:
%1</source>
        <translation>Impossibile accedere alla libreria predefinita:
%1</translation>
    </message>
    <message>
        <source>Failed to create default library:
%1</source>
        <translation>Impossibile creare la libreria predefinita:
%1</translation>
    </message>
    <message>
        <source>Downloading default library...</source>
        <translation>Sto scaricando la libreria predefinita...</translation>
    </message>
    <message>
        <source>Failed to download default library:
%1</source>
        <translation>Impossibile scaricare la libreria predefinita:
%1</translation>
    </message>
    <message>
        <source>The default library has been downloaded.
You can click the &quot;Open&quot; button to view it.</source>
        <translation>La libreria predefinita è stata scaricata.
Premi il pulsante &quot;Apri&quot; per visualizzarla.</translation>
    </message>
    <message>
        <source>Error when downloading the default library: %1</source>
        <translation>Errore durante lo scaricamento della libreria predefinita: %1</translation>
    </message>
    <message>
        <source>Failed to download default library:
 %1</source>
        <translation>Impossibile scaricare la libreria predefinita:
%1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <source>%1 organizes files by libraries. 
Do you like to download your default library?</source>
        <translation>%1 organizza i file in librerie.
Vuoi scaricare la tua libreria predefinita?</translation>
    </message>
    <message>
        <source>Skip</source>
        <translation>Salta</translation>
    </message>
    <message>
        <source>Run in Background</source>
        <translation>Esegui in background</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>Finisci</translation>
    </message>
    <message>
        <source>Download Default Library</source>
        <translation>Scarica libreria predefinita</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
</context>
<context>
    <name>LoadMoreButton</name>
    <message>
        <source>load more</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Add an account</source>
        <translation>Aggiungi un account</translation>
    </message>
    <message>
        <source>Single Sign On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Re-login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Logging in...</source>
        <translation>Sto entrando...</translation>
    </message>
    <message>
        <source>Network Error:
 %1</source>
        <translation>Errore di Rete:
%1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Attenzione:&lt;/b&gt; Il certificato ssl di questo server non è verificato, procedere comunque?</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>inserisci l&apos;indirizzo del server</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 non è un nome valido per il server</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>Inserisci il nome utente</translation>
    </message>
    <message>
        <source>Please enter the computer name</source>
        <translation>Per favore inserisci il nome del computer</translation>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation>Impossibile salvare l&apos;account corrente</translation>
    </message>
    <message>
        <source>Two Factor Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 Server Address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server address must not be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is not a valid server address. It has to start with &apos;https://&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Inserisci la password</translation>
    </message>
    <message>
        <source>Enter the two factor authentication token</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect email or password</source>
        <translation>Email o password sbagliati</translation>
    </message>
    <message>
        <source>Logging in too frequently, please wait a minute</source>
        <translation>Ti stai autenticando con troppa frequenza, per favore attendi un minuto</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Errore Interno del Server</translation>
    </message>
    <message>
        <source>Failed to login: %1</source>
        <translation>Impossibile effettuare il login: %1</translation>
    </message>
    <message>
        <source>Failed to login</source>
        <translation>Accesso fallito</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>logo</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>or http://192.168.1.24:8000</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password:</source>
        <translation>Password:</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>stato testo</translation>
    </message>
    <message>
        <source>Computer Name:</source>
        <translation>Nome del Computer:</translation>
    </message>
    <message>
        <source>Email / Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>e.g. Jim&apos;s laptop</source>
        <translation>e.g. PC di Mario Rossi</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Accesso</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancella</translation>
    </message>
</context>
<context>
    <name>LogoutView</name>
    <message>
        <source>You are logout. Please </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add an account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Refresh</source>
        <translation>Aggiorna</translation>
    </message>
</context>
<context>
    <name>MessageListener</name>
    <message>
        <source>failed to load ccnet config dir </source>
        <translation>impossibile caricare la cartella di configurazione ccnet</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is unsynced. 
Reason: Deleted on server</source>
        <translation>&quot;%1&quot; è non sincronizzato.
Motivo: Cancellato sul server</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is synchronized</source>
        <translation>&quot;%1&quot; è sincronizzato</translation>
    </message>
    <message>
        <source>Files uploaded to &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File %1 conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other application. This file will be updated when you close the application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync folder %1
Some file in this folder is locked by other application. This folder will be updated when you close the application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other user on the server. Update to this file is not uploaded.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path is ended with space or period and cannot be created on Windows.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path contains invalid characters. It is not synced to this computer.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to index file %1
Please check file permission and disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync. 
Access denied to service</source>
        <translation>&quot;%1&quot; sincronizzazione fallita.
Accesso rifiutato al servizio</translation>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync.
The library owner&apos;s storage space is used up.</source>
        <translation>&quot;%1&quot; sincronizzazione fallita.
Lo spazio del proprietario della libreria è esaurito.</translation>
    </message>
</context>
<context>
    <name>PrivateShareDialog</name>
    <message>
        <source>Share %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter the group name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter user name or email address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updated successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share Operation Failed: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get share information of the folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get your groups and contacts information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the group name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No such group &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Already shared to group %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Already shared to user %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share To:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read-Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read-Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>synchronized</source>
        <translation>sincronizzato</translation>
    </message>
    <message>
        <source>indexing files</source>
        <translation>indicizzazione dei documenti</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation>inizializzazione sincronizzazione</translation>
    </message>
    <message>
        <source>downloading</source>
        <translation>scaricamento</translation>
    </message>
    <message>
        <source>uploading</source>
        <translation>caricamento</translation>
    </message>
    <message>
        <source>sync merging</source>
        <translation>fusione sincronia</translation>
    </message>
    <message>
        <source>waiting for sync</source>
        <translation>in attesa di sincronizzazione</translation>
    </message>
    <message>
        <source>server not connected</source>
        <translation>server non connesso</translation>
    </message>
    <message>
        <source>server authenticating</source>
        <translation>autenticazione del server</translation>
    </message>
    <message>
        <source>auto sync is turned off</source>
        <translation>sincronizzazione automatica disattivata</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>sconosciuto</translation>
    </message>
    <message>
        <source>Server has been removed</source>
        <translation>Il server è stato rimosso</translation>
    </message>
    <message>
        <source>You have not logged in to the server</source>
        <translation>Non ti sei autenticato nel server</translation>
    </message>
    <message>
        <source>You do not have permission to access this library</source>
        <translation>Non hai i permessi per accedere a questa libreria</translation>
    </message>
    <message>
        <source>The storage space of the library owner has been used up</source>
        <translation>Lo spazio di archiviazione del proprietario della libreria è esaurito</translation>
    </message>
    <message>
        <source>Remote service is not available</source>
        <translation>Servizio remoto non disponibile</translation>
    </message>
    <message>
        <source>Access denied to service</source>
        <translation>Accesso negato al servizio</translation>
    </message>
    <message>
        <source>Internal data corrupted</source>
        <translation>Dati interni corrotti</translation>
    </message>
    <message>
        <source>Failed to start upload</source>
        <translation>Fallito avvio upload</translation>
    </message>
    <message>
        <source>Error occured in upload</source>
        <translation>Errore durante l&apos;upload</translation>
    </message>
    <message>
        <source>Failed to start download</source>
        <translation>Fallito avvio download</translation>
    </message>
    <message>
        <source>Error occured in download</source>
        <translation>Errore durante il download</translation>
    </message>
    <message>
        <source>Library is damaged on server</source>
        <translation>Libreria danneggiata sul server</translation>
    </message>
    <message>
        <source>Conflict in merge</source>
        <translation>Conflitto durante l&apos;unione</translation>
    </message>
    <message>
        <source>Server version is too old</source>
        <translation>La versione del server è troppo vecchia </translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Errore sconosciuto</translation>
    </message>
    <message>
        <source>Permission denied on server. Please try resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve proxy address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot connect to server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to establish secure connection. Please check server SSL certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer was interrupted. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer timed out. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unhandled http redirect from server. Please check server cofiguration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bad request</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal data corrupt on the client. Please try resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enough memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to write data on the client. Please check disk space or folder permissions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Storage quota full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library deleted on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library damaged on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation>Lo spazio di archiviazione è esaurito.</translation>
    </message>
    <message>
        <source>Internal server error</source>
        <translation>Errore interno del server</translation>
    </message>
    <message>
        <source>Your %1 client is too old</source>
        <translation>Il tuo client %1 è troppo vecchio</translation>
    </message>
    <message>
        <source>Failed to sync this library</source>
        <translation>Fallita la sincronia di questa libreria</translation>
    </message>
    <message>
        <source>Files are locked by other application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library is deleted on server</source>
        <translation>La liberia è stata cancellata sul server</translation>
    </message>
    <message>
        <source>Error when accessing the local folder</source>
        <translation>Errore durante l&apos;accesso della cartella locale</translation>
    </message>
    <message>
        <source>initializing...</source>
        <translation>inizializzazione...</translation>
    </message>
    <message>
        <source>Failed to index local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to check server information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to create local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to merge local file changes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect password. Please download again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>connecting server...</source>
        <translation>connessione al server...</translation>
    </message>
    <message>
        <source>indexing files...</source>
        <translation>indicizzazione dei documenti...</translation>
    </message>
    <message>
        <source>Downloading file list...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading files...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Creating folder...</source>
        <translation>Creazione cartella...</translation>
    </message>
    <message>
        <source>Merge file changes...</source>
        <translation>Unisci i cambiamenti del file..</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <source>checking server info...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Canceling</source>
        <translation>Cancellazione</translation>
    </message>
    <message>
        <source>Canceled</source>
        <translation>Cancellato</translation>
    </message>
    <message>
        <source>SSL Error</source>
        <translation>Errore SSL</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Errore di Rete: %1</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation>Errore del Server</translation>
    </message>
    <message>
        <source>failed to open certs database</source>
        <translation>Fallita apertura del database certs</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; doesn&apos;t exist in &quot;%2&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 couldn&apos;t find an application to open file %2</source>
        <translation>%1 impossibile trovare un&apos;applicazione per aprire il file %2</translation>
    </message>
    <message>
        <source>Created library &quot;%1&quot;</source>
        <translation>Creata la libreria &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>Cancellata la libreria &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Rename %1 to</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to download item &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>copy failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Added</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Removed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Renamed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Added or modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Moved</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Added directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Removed directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Renamed directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Moved directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>directories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>and %1 more</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reverted library to status at</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reverted file &quot;%1&quot; to status at %2.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recovered deleted directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Changed library name or description</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Auto merge by %1 system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Just now</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 day ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 days ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 minute ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;Not Part of Certificate&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Found another running process of %1, kill it and start a new one?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to start %1 due to the failure of shutting down the previous process</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync this library to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync this folder to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Readonly Folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PDF Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Text Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audio File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Word Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PowerPoint Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Excel Document</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with system path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with an existing library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>uploading file list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path is invalid</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error when indexing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path ends with space or period character</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path contains invalid characters like &apos;|&apos; or &apos;:&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to open file cache database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReliablePostFileTask</name>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoDetailDialog</name>
    <message>
        <source>Library &quot;%1&quot;</source>
        <translation>Libreria &quot;%1&quot;</translation>
    </message>
    <message>
        <source>This library is not downloaded yet</source>
        <translation>Questa libreria non è ancora stata scaricata</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>Errore:</translation>
    </message>
    <message>
        <source>every %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>RepoIcon</source>
        <translation>RepoIcon</translation>
    </message>
    <message>
        <source>RepoName</source>
        <translation>RepoName</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descrizione:</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation>Etichetta di Testo</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Proprietario:</translation>
    </message>
    <message>
        <source>Last Modified:</source>
        <translation>Ultima Modifica:</translation>
    </message>
    <message>
        <source>mtime</source>
        <translation>mtime</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <source>Local Path:</source>
        <translation>Percorso Locale:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Stato:</translation>
    </message>
    <message>
        <source>RepoStatus</source>
        <translation>RepoStatus</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Sync Interval:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiuso</translation>
    </message>
</context>
<context>
    <name>RepoItemDelegate</name>
    <message>
        <source>, %1%2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>, %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This library has not been downloaded</source>
        <translation>Questa libreria non è stata scaricata</translation>
    </message>
</context>
<context>
    <name>RepoService</name>
    <message>
        <source>Unable to open file &quot;%1&quot; from nonexistent library &quot;%2&quot;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoTreeModel</name>
    <message>
        <source>Recently Updated</source>
        <translation>Aggiornamenti Recenti</translation>
    </message>
    <message>
        <source>My Libraries</source>
        <translation>Le mie Librerie</translation>
    </message>
    <message>
        <source>Sub Libraries</source>
        <translation>Sotto Libreria</translation>
    </message>
    <message>
        <source>Shared with me</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with all</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with groups</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Synced Libraries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>sync initializing</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoTreeView</name>
    <message>
        <source>Disable auto sync</source>
        <translation>Disattiva auto sync</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>Attiva auto sync</translation>
    </message>
    <message>
        <source>Show &amp;details</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show details of this library</source>
        <translation>Mostra dettagli di questa libreria</translation>
    </message>
    <message>
        <source>&amp;Sync this library</source>
        <translation>&amp;Sincronizza questa libreria</translation>
    </message>
    <message>
        <source>Sync this library</source>
        <translation>Sincronizza questa libreria</translation>
    </message>
    <message>
        <source>Recently Updated</source>
        <translation>Aggiornamenti Recenti</translation>
    </message>
    <message>
        <source>Sync &amp;now</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync this library immediately</source>
        <translation>Sincronizza questa libreria immediatamente</translation>
    </message>
    <message>
        <source>&amp;Cancel download</source>
        <translation>&amp;Cancella download</translation>
    </message>
    <message>
        <source>Cancel download of this library</source>
        <translation>Cancella download di questa libreria</translation>
    </message>
    <message>
        <source>&amp;Open folder</source>
        <translation>&amp;Apri cartella</translation>
    </message>
    <message>
        <source>open local folder</source>
        <translation>apri cartella locale</translation>
    </message>
    <message>
        <source>&amp;Open local folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Unsync</source>
        <translation>&amp;Desincronizza</translation>
    </message>
    <message>
        <source>unsync this library</source>
        <translation>desincronizza questa libreria</translation>
    </message>
    <message>
        <source>&amp;View on cloud</source>
        <translation>&amp;Visualizza sul server</translation>
    </message>
    <message>
        <source>view this library on seahub</source>
        <translation>visualizza questa libreria su seahub</translation>
    </message>
    <message>
        <source>Share to user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share this library to a user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share to group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share this library to a group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Open cloud file browser</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>open this library in embedded Cloud File Browser</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Resync this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>unsync and resync this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set sync &amp;Interval</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>set sync interval for this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to unsync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to resync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to overwrite the file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync library &quot;%1&quot;</source>
        <translation>Fallita desincronizzazione libreria &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Are you sure you want to leave the share &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leaving share failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Fallita la cancellazione di questo task:

%1</translation>
    </message>
    <message>
        <source>The download has been canceled</source>
        <translation>Questo download è stato cancellato</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to overwrite file &quot;%1&quot; with itself</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to delete file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to upload file: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync Interval (In seconds):</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set Sync Internval For Library &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReposTab</name>
    <message>
        <source>Search libraries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>riprova</translation>
    </message>
    <message>
        <source>Failed to get libraries information&lt;br/&gt;Please %1</source>
        <translation>Tentativo fallito di ottenere informazioni delle librerie&lt;br/&gt;Per favore %1</translation>
    </message>
</context>
<context>
    <name>SeafileApiClient</name>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;Attenzione:&lt;/b&gt; Il certificato ssl di questo server non è affidabile, procedere comunque?</translation>
    </message>
</context>
<context>
    <name>SeafileApplet</name>
    <message>
        <source>failed to add default account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to initialize log: %s</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileLinkDialog</name>
    <message>
        <source>%1 Internal Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 Web Link:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 Protocol Link:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileRpcClient</name>
    <message>
        <source>failed to load ccnet config dir %1</source>
        <translation>fallita lettura cartella di configurazione ccnet %1</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Errore sconosciuto</translation>
    </message>
</context>
<context>
    <name>SeafileTrayIcon</name>
    <message>
        <source>Disable auto sync</source>
        <translation>Disabilita sincronizzazione automatica</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>Abilita sincronizzazione automatica</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quit</translation>
    </message>
    <message>
        <source>Show main window</source>
        <translation>Mostra finestra principale</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Open %1 &amp;folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>open %1 folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open &amp;logs folder</source>
        <translation>Apri la cartella dei log</translation>
    </message>
    <message>
        <source>Show file sync errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Informazioni</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>Mostra il box About</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>&amp;Guida in linea</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>auto sync is disabled</source>
        <translation>la sincronizzazione automatica è disabilitata</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>open %1 log folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>open %1 online help</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>alcuni server non sono connessi</translation>
    </message>
</context>
<context>
    <name>SearchResultListView</name>
    <message>
        <source>&amp;Show in folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to search&lt;br/&gt;Please %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ServerStatusDialog</name>
    <message>
        <source>Servers connection status</source>
        <translation>Stato di connessione dei server</translation>
    </message>
    <message>
        <source>connected</source>
        <translation>connesso</translation>
    </message>
    <message>
        <source>disconnected</source>
        <translation>disconnesso</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>SetRepoPasswordDialog</name>
    <message>
        <source>Please provide the library password</source>
        <translation>Prego, inserire la password della libreria</translation>
    </message>
    <message>
        <source>Provide the password for library %1</source>
        <translation>Inserisci la password per la libreria %1</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Prego, inserisci la password</translation>
    </message>
    <message>
        <source>Incorrect password</source>
        <translation>Password non corretta</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Errore sconosciuto</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Auto start %1 after login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide %1 Icon from the dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have changed languange. Restart to apply it?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The proxy host address can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The proxy port is incorrect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy username can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy password can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Hide main window when started</source>
        <translation>Nascondi la finestra principale dopo l&apos;avvio</translation>
    </message>
    <message>
        <source>Notify when libraries are synchronized</source>
        <translation>Notifica quando le librerie sono sincronizzate</translation>
    </message>
    <message>
        <source>Enable sync temporary files of MSOffice/Libreoffice</source>
        <translation>Abilita la sincronizzazione dei file temporanei di MSOffice/Libreoffice</translation>
    </message>
    <message>
        <source>Download speed limit (KB/s):</source>
        <translation>Velocità massima di download (KB/s):</translation>
    </message>
    <message>
        <source>Upload speed limit (KB/s):</source>
        <translation>Velocità massima di caricamento (kB/s):</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Base</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library</source>
        <translation>Non desincronizzare automaticamente una libreria</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when its local directory is removed or unaccessible for other reasons.</source>
        <translation>Non desincronizzare automaticamente una libreria quando la sua cartella locale è rimossa o non accessibile per altre ragioni.</translation>
    </message>
    <message>
        <source>Do not unsync a library when not found on server</source>
        <translation>Non sincronizzare una libreria quando non nel server</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when it&apos;s not found on server</source>
        <translation>Non desincronizzare una libreria quando non presente nel server</translation>
    </message>
    <message>
        <source>Enable FinderSync Extension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable Explorer Extension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check for updates automatically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not verify server certificate in HTTPS syncing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable syncing with an existing folder with a different name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avanzato</translation>
    </message>
    <message>
        <source>Language (need restart)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Language</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>0</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy server requires a password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancella</translation>
    </message>
</context>
<context>
    <name>SharedItemDelegate</name>
    <message>
        <source>Read Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove Share</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedItemsTableModel</name>
    <message>
        <source>Click to edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedLinkDialog</name>
    <message>
        <source>Share Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share link:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Direct Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShibLoginDialog</name>
    <message>
        <source>Login with Shibboleth</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SslConfirmDialog</name>
    <message>
        <source>Untrusted Connection</source>
        <translation>Connessione Non Affidabile</translation>
    </message>
    <message>
        <source>%1 uses an invalid security certificate. The connection may be insecure. Do you want to continue?</source>
        <translation>%1 utilizza un certificato di sicurezza non valido. La connessione potrebbe essere insicura. Vuoi continuare?</translation>
    </message>
    <message>
        <source>Current RSA key fingerprint is %1</source>
        <translation>Il fingerprint della chiave corrente RSA è %1</translation>
    </message>
    <message>
        <source>Previous RSA key fingerprint is %1</source>
        <translation>Il fingerprint della chiave RSA precedente è %1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation>Ricorda la mia scelta</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
</context>
<context>
    <name>StarredFilesListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Apri</translation>
    </message>
    <message>
        <source>Open this file</source>
        <translation>Apri questo file</translation>
    </message>
    <message>
        <source>view on &amp;Web</source>
        <translation>Visualizza sul &amp;Web</translation>
    </message>
    <message>
        <source>view this file on website</source>
        <translation>vedi questo file sul sito</translation>
    </message>
</context>
<context>
    <name>StarredFilesTab</name>
    <message>
        <source>retry</source>
        <translation>riprova</translation>
    </message>
    <message>
        <source>Failed to get starred files information&lt;br/&gt;Please %1</source>
        <translation>Tentativo fallito di ottenere informazioni dei preferiti&lt;br/&gt;Per favore %1</translation>
    </message>
    <message>
        <source>You have no starred files yet.</source>
        <translation>Non hai nessun file preferito.</translation>
    </message>
</context>
<context>
    <name>SyncErrorsDialog</name>
    <message>
        <source>File Sync Errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No sync errors.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SyncErrorsTableModel</name>
    <message>
        <source>Double click to open the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UninstallHelperDialog</name>
    <message>
        <source>Uninstall %1</source>
        <translation>Disinstalla %1</translation>
    </message>
    <message>
        <source>Do you want to remove the %1 account information?</source>
        <translation>Vuoi elimiare le informazioni dell&apos;account %1?</translation>
    </message>
    <message>
        <source>Removing account information...</source>
        <translation>Eliminazione delle informazioni dell&apos;account...</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>text</source>
        <translation>testo</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
</context>
</TS>